@@ -1,7 +1,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: device.cpp,v 1.1.1.1 2003/03/25 00:13:21 dadler Exp $
+// $Id: device.cpp,v 1.2 2004/05/28 07:05:26 dadler Exp $
 
 #include "device.h"
 #include "rglview.h"
@@ -64,6 +64,13 @@ void Device::close(void)
   delete this;
 }
 
+#ifdef _WIN32
+void Device::bringToTop(void)
+{
+  window->bringToTop();
+}
+#endif
+
 //
 // scene management:
 //
@@ -76,7 +83,7 @@ bool Device::clear(TypeID stackTypeID)
   return success;
 }
 
-bool Device::add(SceneNode* node) 
+bool Device::add(SceneNode* node)
 {
   bool success;
   if ( success = scene->add(node) )
@@ -85,7 +92,7 @@ bool Device::add(SceneNode* node)
 }
 
 bool Device::pop(TypeID stackTypeID)
-{  
+{
   bool success;
   if ( success = scene->pop(stackTypeID) )
     rglview->update();
@@ -93,7 +100,7 @@ bool Device::pop(TypeID stackTypeID)
 }
 
 //
-// export 
+// export
 //
 
 bool Device::snapshot(int format, const char* filename)
