@@ -4,7 +4,7 @@
 // C++ header file
 // This file is part of RGL
 //
-// $Id: win32gui.h,v 1.1.1.1 2003/03/25 00:13:21 dadler Exp $
+// $Id: win32gui.h,v 1.3 2004/05/28 12:06:31 dadler Exp $
 
 
 #include "gui.h"
@@ -19,13 +19,13 @@ namespace gui {
   public:
   
     Win32GUIFactory(HINSTANCE inModuleHandle);
-    ~Win32GUIFactory();
+    virtual ~Win32GUIFactory();
   
     WindowImpl* createWindowImpl(Window* window);
       
   };
 
-};
+} // namespace gui
 
 
 #endif /* WIN32_GUI_H */
